OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Cruscotto",
    "Dashboard app" : "Cruscotto",
    "\"{title} icon\"" : "\"Icona {title}\"",
    "Customize" : "Personalizza",
    "Edit widgets" : "Modifica widget",
    "Get more widgets from the App Store" : "Ottieni altri widget dal negozio delle applicazioni",
    "Weather service" : "Servizio meteo",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Per la tua riservatezza, i dati meteorologici sono richiesti dal tuo server Nextcloud per tuo conto, per cui il servizio meteo non riceve informazioni personali.",
    "Weather data from Met.no" : "Dati meteo da Met.no",
    "geocoding with Nominatim" : "geocodifica conh Nominatim",
    "elevation data from OpenTopoData" : "dati di elevazione da OpenTopoData",
    "Weather" : "Meteo",
    "Status" : "Stato",
    "Good morning" : "Buongiorno",
    "Good morning, {name}" : "Buongiorno, {name}",
    "Good afternoon" : "Buon pomeriggio",
    "Good afternoon, {name}" : "Buon pomeriggio, {name}",
    "Good evening" : "Buona sera",
    "Good evening, {name}" : "Buona sera, {name}",
    "Hello" : "Ciao",
    "Hello, {name}" : "Ciao {name}",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Inizia la tua giornata aggiornato\n\nIl cruscotto di Nextcloud è il tuo punto di partenza della giornata, che offre una panoramica dei prossimi appuntamenti, email urgenti, messaggi di chat, nuove richieste, ultimi tweet e molto altro ancora! Gli utenti possono aggiungere i widget che preferiscono e modificare lo sfondo a proprio piacimento.",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! Users can add the widgets they like and change the background to their liking." : "Inizia la giornata informato\n\nIl cruscotto di Nextcloud è il tuo punto di partenza della giornata, che offre una panoramica di prossimi appuntamenti, email urgenti, messaggi di chat, nuove richieste, ultimi tweet e molto altro ancora! Gli utenti possono aggiungere i widget che preferiscono e modificare lo sfondo a proprio piacimento."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
